from fastapi import APIRouter, BackgroundTasks
from pydantic import BaseModel

from ..utils.email_code import send_email
from ..handlers import signup_handlers

router = APIRouter(tags=['signup'], prefix='/signup')


class SignUpAccount(BaseModel):
    username: str
    password: str
    email: str
    code: str


@router.get('/code/{email}')
async def get_code(email: str, background_tasks: BackgroundTasks):
    background_tasks.add_task(send_email, email)
    return {'code': 10000, 'msg': 'success'}


@router.post('')
async def sign_up(signup_account: SignUpAccount):
    verification_res = await signup_handlers.verify_code(signup_account.email, signup_account.code)

    if not verification_res:
        return {'code': 10001, 'msg': 'Code is incorrect'}



